# samdasoo-content

![image](https://github.com/dMario24/samdasoo-content/assets/134017660/76e04c58-2d31-4771-99ab-ca3988707490)

- 이 프로그램은 삼다수의 주요 성분 지표를 알려줍니다.

### use
```bash
$ pip install samdasoo-content

$ python
>>> import samdasoo_content.content as sam
>>> sam.k()
1.5
>>> sam.ca()
2.5
>>> 
```

### test
```bash
# all checkt test
$ pytest

# I want to run the specific function and view the output
$ pytest -s tests/test_content.py::test_rmrf
                                                                             
                             ^7JYPJ:                                         
                            7PGP5B&B~                                        
                           ~GPP55B#&G.                                       
                          :Y5YYYPGB#B7                                       
                         ~Y5YYJYB#BBB7                                       
                         ~55???5B##BB?                                       
                         ~5Y!!?5BB#BPY.                                      
                         7Y7~~75GB##PY                                       
                         ?YJ?JY5GBBGG5                                       
                        ~5?~~~75PGBP5G^              .^!?JJ~.                
                        :JJ!~~!YPPGBYGY           .^7JYYYPBBY^::.            
                         ~Y7~~~?P5GBPYG^       .:7JJJJY5BGP5Y???PY!.         
                         .JJ~!!7Y55PG5PY   .:~!?7?J^!?P#G5PY?!~!PBB5~        
                          ~J7!~7J5PGGGGGJ77777!~~!J~JG##5PJ7!~^!PBBB5.       
                          :?JJJYPPY?YYGPGGJ!^::::~55G#@PP57!^:~75GGBG^       
                          ?Y55?JYP57?YYP5GGJ7!!?JPBG#&@5P7~^^^^~JGGGB!       
                          .J?P55P55PJJY5P5B#PPGB##BBB#BPGPP5PP5YYPPPG7       
                       ^?7JPYJPJ5YY5PJJ5GGG&&&&#BBBGPJ5&GJ7!~~!YPGBBBY.      
                   ^7~^?G&#BG5Y5?YJJY55G###BBGBPYYJ~. ^BPY7!7JPGPGB###Y      
                ..!?!!5#@&&##BJ?!^^!7J5PB&#P5P57^.    :BBPYYY7!7J55PGG5:     
              ~7?7Y5PPB#&&&#G?~!7!~7?YYJG&&#GPPGG5PJ  :PGY7!~!!!7?JYPGGP7    
           ^7^J#5PPJ!!777YJ7~7YYYJ~!JY5YP&&#BBGPGB#G?.755?~?J?7?JY5GB####Y.  
          :?J5BPP5?777!7~~?!JGYJY!..!YYPG#&#BBGPB&#GB5YP5?JPPGGBBBB##&&@#5.  
        .~JYYJJ55Y5YYY7JP???B5JJY!.:75YGBB&&&#BGB&###GPPP?J7?YPBBG###&&@B^   
       :7?YJ~:!YJ55P5YJJY57?BGYJYJ!7Y55BPG#&&&#B&@@&#P5PPPPJ?77?JY5PGBB&J    
      .7J??77~!?5P55?!^7JPYJ5BB5YYYYY5GGPP##&&&#&@&BGPPGPY?J5PBBBBBB#&##^    
    .:!Y55J!?77JY5YJ?7!?Y5PJYY55YYYJ5PPPPP5P#&&&&B#BGPPGGGPPGGBB###BB##B^    
  .!??YYY5J~!Y??YY5YYJJJYPGJYYJ?JJJYY5PPPP55G#&@#&GPPPG##PY5GGGGGGGBB###B~   
  !PY!?JYYJ:^5Y?Y5Y??J?Y55YYY5Y5YYJ55YPPPPPPGPBB#&GPGG#B55GBBP5PP55PGB##&P   
  ~??!!?55Y7JPPYPYYJJYJJJJJYYYJ55JJY55PPPPGGGGBPG&#GG&B5YJ5GP5PGGPGBGPBB##^  
  :?!^~5YYP55PPJ5YJ?7?JYYJY?!7JYY555YPPPPPPPPGP5P&@&@#PP!J5Y5PPPPP55BP5G#@?  
   ~77?G5?PP5YY5YJ?!!JYPPP5J5Y7J5G555PPPPG55#BG&@@&&&GP?7JYPYY55YJ?PBBPP#@7  
    ^!YBPJYP5JYJJJ?~~7?Y5GPP&#P?YGGGGGGGP55@@@@@&&&@BGJJYJ555555J7Y5PGGG#B.  
      :J5J?JP5Y?!!7^^!?JYYPB###5J#BBBBGGGY&@&&&&&&@#BPJPY5PYJY555?7YPPPBG^   
        75J75PY!^^:..~?5YY55#&GPJ#GPGGGBGY&@&&&&&&@BBYPPJ#BPGB5PJ^:?P5PB~    
        .?Y?GGY7~^:::^~?P5PBG#J?J5JJBBBBBG#@@&&&&@#BPPBPG##BBBGP?~~JPGG7     
         .?YYB57~^:::^^!YGPGG&&##&#5G#B####&&&&&@@#BPG#G#&#BB##GJ7?5GB?      
          .JY5G5~^:^^^^~?BB&P#@##BPPG&&#&&&&&#&@@@#BGB###&&#####B55GBJ       
           ^YJ5B57~::^^^?B##P&#5Y5GBB#@&&&&&&&#&&&#BB##&&&@&&#BBBBB#Y        
            ~J##BGP?7?JYG#&GB@BPB#&###&@&&&&&@@@@&##&&&&&&&&&#####BY.        
             !JY5PPPPB####GB@&&&&&&G#&&&#&&&@&#GP#@&&@@&&&&###&&&#J.         
              ^?5G5P5BGBGB#&B5GPPGB&@&&&@&&#G5Y5#@#&@&@&&&&&&&@&B7           
               :JBB#G5G&&&&&G#@BB#&&&##BBGG5JYB&G##B#&&&&&@@@&#J.            
                ~PP55GBB&B&@&B&G#B#BG5P555Y5B&BPYG&#G#&&####BGG5~            
                 ^5GGGBB&@@&&#PJY?JJYYYYYPB#BP5PPP#&#GB@&#BGGPBBG^           
                  :5GP5YP###BB!~Y??JYYYPB##PPPP5JP##&&GB&&#BB###G:           
                   !PY??#&G5PJ!!?5?J5B&B5YPB#BPY75B##&&&&######BGJ           
                   ~5J?#@GGBG?Y5GB##G55BBBG5YPG7JP&#####&##GGGGBBB!          
                   .7J#@BBBBBB&@&#GPGGPPGB##5?75B&#B#&#&&&&&###&&#Y          
                   .YGBGG##BBB&B5P##BPGBBPYYJYB&#BB####&&&&&####&&P.         
                   !#PGB&G55Y5PGG5YP&#GP5J?5B#####################&?         
                  ^BG&GG&55J7J###BG55##GJP&&###&&&&&##########B##&@#^        
                 .PP#G5&BY5JJBGGGG#BP5B&&PP###########BBBBBBB##&&&@@P        
                  ^BPPB#5GG5#GGPP#5GBP5B##PYBBBBGBBGPPPBBB##&&&&&&&#&!       
                  ~PGPP5JPPYP&B5&PY5PBGYBBBGJ5PPP5Y5PB##BB&&&&&&&&&##P       
                 :JPGYYP?PGY?GY##PPGGBBPY5YB#JJJJ5G#BBB#BGB&&&&##&&###~      
                 ?5#PJYY5P55JJG&#PP5B##GBB##&&PP##GGGBB##GB&&&&&&&&###P      
                ^5BBY?5#GPPPPPB&#PPPGPG###BBGB#BBGGGGB#B##B#&&&&&&&&###^     
                7PB5Y?B#PGP5P5#&#BGPBGGGGGGGGGGGGGGGBBBBB#BB&&B###&&##&Y     
               .YBP5PP@BP55YGP#&&BG5GBBGGGGGGPGGGGBBBB####BB&&B###&&###B.    
               !PBPPYB@GGBPP#B#&&##PPBBBBBGGBBBBBBBGBBB####B&&B##&#&&##&!    
              .5BPPYG&&GGPGG&B#&&##PPBBGGBBBBBBBBBGGGBBBBB###&&####&&##&Y    
              !PBP5Y5&###BPP&B#&&##BPBBBGBBBB####BGGBBBBBB##B&&B#&##&&#&G    
             .JPGGPB5&#PYY5B&BB&&#&&PGBBBGBB######BB##BGGB#&G#&BBB##@&#&#:   
```